@@ -13,32 +13,29 @@
 # limitations under the License.
 
 from typing import Dict
-from dlk.utils.config import BaseConfig
-from . import scheduler_register, scheduler_config_register, BaseScheduler
+from . import scheduler_register, scheduler_config_register, BaseScheduler, BaseSchedulerConfig
 from torch.optim.lr_scheduler import LambdaLR
 import torch.optim as optim
 
 
 @scheduler_config_register("constant_warmup")
-class ConstantWarmupScheduleConfig(BaseConfig):
+class ConstantWarmupScheduleConfig(BaseSchedulerConfig):
+    default_config = {
+            "config": {
+                "num_warmup_steps": 0,
+                },
+            "_name": "constant_warmup",
+            }
     """Config for ConstantWarmupSchedule
 
     Config Example:
-        >>> {
-        >>>     "config": {
-        >>>         "last_epoch": -1,
-        >>>         "num_warmup_steps": 0,
-        >>>     },
-        >>>     "_name": "constant_warmup",
-        >>> }
+        default_config
     """
     def __init__(self, config: Dict):
         super(ConstantWarmupScheduleConfig, self).__init__(config)
         config = config['config']
-        self.last_epoch = config["last_epoch"]
         self.num_warmup_steps = config["num_warmup_steps"]
         self.post_check(config, used=[
-            "last_epoch",
             "num_warmup_steps",
         ])
 
@@ -59,11 +56,10 @@ class ConstantWarmupSchedule(BaseScheduler):
 
         """
         num_warmup_steps = self.config.num_warmup_steps
-        last_epoch = self.config.last_epoch
 
         def lr_lambda(current_step: int):
             if current_step < num_warmup_steps:
                 return float(current_step) / float(max(1.0, num_warmup_steps))
             return 1.0
 
-        return LambdaLR(self.optimizer, lr_lambda, last_epoch=last_epoch)
+        return LambdaLR(self.optimizer, lr_lambda, last_epoch=-1)
