@@ -1,4 +1,4 @@
-# Copyright 2021 cstsunfu. All rights reserved.
+# Copyright cstsunfu. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,54 +24,55 @@ from dlk.data.postprocessors import postprocessor_register, postprocessor_config
 from dlk.utils.logger import Logger
 from dlk.utils.vocab import Vocabulary
 from tokenizers import Tokenizer
+from dlk.utils.io import open
 import torchmetrics
 logger = Logger.get_logger()
 
 
 @postprocessor_config_register('seq_lab')
 class SeqLabPostProcessorConfig(IPostProcessorConfig):
+    default_config = {
+            "_name": "seq_lab",
+            "config": {
+                "meta": "*@*",
+                "use_crf": False, # use or not use crf
+                "word_ready": False, # already gather the subword first token as the word rep or not
+                "ignore_position": True, # calc the metrics, whether ignore the ground_truth and predict position info.( if set to true, only focus on the entity content not position.)
+                "ignore_char": " ", # if the entity begin or end with this char, will ignore these char
+                # "ignore_char": " ()[]-.,:", // if the entity begin or end with this char, will ignore these char
+                "meta_data": {
+                    "label_vocab": 'label_vocab',
+                    "tokenizer": "tokenizer",
+                },
+                "input_map": {
+                    "logits": "logits",
+                    "predict_seq_label": "predict_seq_label",
+                    "_index": "_index",
+                },
+                "origin_input_map": {
+                    "uuid": "uuid",
+                    "sentence": "sentence",
+                    "input_ids": "input_ids",
+                    "entities_info": "entities_info",
+                    "offsets": "offsets",
+                    "special_tokens_mask": "special_tokens_mask",
+                    "word_ids": "word_ids",
+                    "label_ids": "label_ids",
+                },
+                "save_root_path": ".",  # save data root dir
+                "save_path": {
+                    "valid": "valid",  # relative dir for valid stage
+                    "test": "test",    # relative dir for test stage
+                },
+                "start_save_step": 0,  # -1 means the last
+                "start_save_epoch": -1,
+                "aggregation_strategy": "max", # AggregationStrategy item
+                "ignore_labels": ['O', 'X', 'S', "E"], # Out, Out, Start, End
+            }
+        }
     """Config for SeqLabPostProcessor
 
-    Config Example:
-        >>> {
-        >>>     "_name": "seq_lab",
-        >>>     "config": {
-        >>>         "meta": "*@*",
-        >>>         "use_crf": false, //use or not use crf
-        >>>         "word_ready": false, //already gather the subword first token as the word rep or not
-        >>>         "ignore_position": true, // calc the metrics, whether ignore the ground_truth and predict position info.( if set to true, only focus on the entity content not position.)
-        >>>         "ignore_char": " ", // if the entity begin or end with this char, will ignore these char
-        >>>         //"ignore_char": " ()[]-.,:", // if the entity begin or end with this char, will ignore these char
-        >>>         "meta_data": {
-        >>>             "label_vocab": 'label_vocab',
-        >>>             "tokenizer": "tokenizer",
-        >>>         },
-        >>>         "input_map": {
-        >>>             "logits": "logits",
-        >>>             "predict_seq_label": "predict_seq_label",
-        >>>             "_index": "_index",
-        >>>         },
-        >>>         "origin_input_map": {
-        >>>             "uuid": "uuid",
-        >>>             "sentence": "sentence",
-        >>>             "input_ids": "input_ids",
-        >>>             "entities_info": "entities_info",
-        >>>             "offsets": "offsets",
-        >>>             "special_tokens_mask": "special_tokens_mask",
-        >>>             "word_ids": "word_ids",
-        >>>             "label_ids": "label_ids",
-        >>>         },
-        >>>         "save_root_path": ".",  //save data root dir
-        >>>         "save_path": {
-        >>>             "valid": "valid",  // relative dir for valid stage
-        >>>             "test": "test",    // relative dir for test stage
-        >>>         },
-        >>>         "start_save_step": 0,  // -1 means the last
-        >>>         "start_save_epoch": -1,
-        >>>         "aggregation_strategy": "max", // AggregationStrategy item
-        >>>         "ignore_labels": ['O', 'X', 'S', "E"], // Out, Out, Start, End
-        >>>     }
-        >>> }
+    Config Example: default_config
     """
 
     def __init__(self, config: Dict):
@@ -98,7 +99,8 @@ class SeqLabPostProcessorConfig(IPostProcessorConfig):
         self._index = self.input_map['_index']
 
         if isinstance(self.config['meta'], str):
-            meta = pkl.load(open(self.config['meta'], 'rb'))
+            with open(self.config['meta'], 'rb') as f:
+                meta = pkl.load(f)
         else:
             raise PermissionError("You must provide meta data(vocab & tokenizer) for ner postprocess.")
 
@@ -124,7 +126,7 @@ class SeqLabPostProcessorConfig(IPostProcessorConfig):
         self.tokenizer = Tokenizer.from_str(tokenizer_config)
 
         self.save_path = self.config['save_path']
-        self.save_root_path = self.config['save_root_path']
+        self.savs_root_path = self.config['save_root_path']
         self.start_save_epoch = self.config['start_save_epoch']
         self.start_save_step = self.config['start_save_step']
 
@@ -159,7 +161,7 @@ class AggregationStrategy(object):
 class SeqLabPostProcessor(IPostProcessor):
     """PostProcess for sequence labeling task"""
     def __init__(self, config:    SeqLabPostProcessorConfig):
-        super(   SeqLabPostProcessor, self).__init__()
+        super(   SeqLabPostProcessor, self).__init__(config)
         self.config = config
         self.label_vocab = self.config.label_vocab
         self.tokenizer = self.config.tokenizer
@@ -309,14 +311,13 @@ class SeqLabPostProcessor(IPostProcessor):
             save_condition = True
         if save_condition:
             save_path = os.path.join(self.config.save_root_path, self.config.save_path.get(stage, ''))
-            if not os.path.exists(save_path):
-                os.makedirs(save_path, exist_ok=True)
             if "current_step" in rt_config:
                 save_file = os.path.join(save_path, f"step_{str(rt_config['current_step'])}_predict.json")
             else:
                 save_file = os.path.join(save_path, 'predict.json')
             logger.info(f"Save the {stage} predict data at {save_file}")
-            json.dump(predicts, open(save_file, 'w'), indent=4, ensure_ascii=False)
+            with open(save_file, 'w') as f:
+                json.dump(predicts, f, indent=4, ensure_ascii=False)
 
     def calc_score(self, predict_list: List, ground_truth_list: List):
         """use predict_list and ground_truth_list to calc scores
@@ -519,7 +520,7 @@ class SeqLabPostProcessor(IPostProcessor):
 
         predicts = []
         for outputs in list_batch_outputs:
-            batch_logits = outputs[self.config.logits].detach()
+            batch_logits = outputs[self.config.logits].detach().cpu().numpy()
             # batch_special_tokens_mask = outputs[self.config.special_tokens_mask]
 
             indexes = list(outputs[self.config._index])
@@ -531,7 +532,7 @@ class SeqLabPostProcessor(IPostProcessor):
                 word_ids = origin_ins[self.config.word_ids]
 
                 rel_token_len = len(word_ids)
-                logits = logits[:rel_token_len].cpu().numpy()
+                logits = logits[:rel_token_len]
 
                 predict = logits.argmax(-1)
                 one_ins = self._process4predict(predict, index, origin_data)
@@ -561,7 +562,7 @@ class SeqLabPostProcessor(IPostProcessor):
 
         predicts = []
         for outputs in list_batch_outputs:
-            batch_logits = outputs[self.config.logits].detach()
+            batch_logits = outputs[self.config.logits].detach().cpu().numpy()
             # batch_special_tokens_mask = outputs[self.config.special_tokens_mask]
 
             indexes = list(outputs[self.config._index])
@@ -582,7 +583,7 @@ class SeqLabPostProcessor(IPostProcessor):
                 special_tokens_mask = np.array(origin_data.iloc[int(index)][self.config.special_tokens_mask][:rel_token_len])
                 offset_mapping = origin_data.iloc[int(index)][self.config.offsets][:rel_token_len]
 
-                logits = logits[:rel_token_len].cpu().numpy()
+                logits = logits[:rel_token_len]
 
                 entity_idx = logits.argmax(-1)
                 labels = []
