@@ -16,43 +16,41 @@ from dlk.utils.config import ConfigTool, BaseConfig
 from dlk.utils.logger import Logger
 from typing import Dict, Callable, Set, List
 from dlk.data.subprocessors import subprocessor_register, subprocessor_config_register, ISubProcessor
+from dlk.utils.io import open
 import pickle as pkl
 import os
 
 logger = Logger.get_logger()
 
+
 @subprocessor_config_register('load')
 class LoadConfig(BaseConfig):
+    default_config = {
+        "_name": "load",
+        "config": {
+            "base_dir": "",
+            "predict": {
+                "meta": "meta.pkl",
+            },
+            "online": "predict",
+            "extend_train": "predict"
+        }
+    }
     """Config for Load
 
     Config Example:
-        >>> {
-        >>>     "_name": "load",
-        >>>     "config":{
-        >>>         "base_dir": "."
-        >>>         "predict":{
-        >>>             "meta": "./meta.pkl",
-        >>>         },
-        >>>         "online": [
-        >>>             "predict", //base predict
-        >>>             {   // special config, update predict, is this case, the config is null, means use all config from "predict", when this is empty dict, you can only set the value to a str "predict", they will get the same result
-        >>>             }
-        >>>         ]
-        >>>     }
-        >>> },
+        default_config
     """
-
     def __init__(self, stage, config):
         super(LoadConfig, self).__init__(config)
         self.config = ConfigTool.get_config_by_stage(stage, config)
-        self.base_dir:str = config.get('config').get("base_dir", ".")
+        self.base_dir: str = config.get('config').get("base_dir", "")
 
 
 @subprocessor_register('load')
 class Load(ISubProcessor):
     """ Loader the $meta, etc. to data
     """
-
     def __init__(self, stage: str, config: LoadConfig):
         super().__init__()
         self.stage = stage
@@ -78,9 +76,10 @@ class Load(ISubProcessor):
         """
 
         logger.info(f"Loading file from {os.path.join(self.base_dir, path)}")
-        return pkl.load(open(os.path.join(self.base_dir, path), 'rb'))
+        with open(os.path.join(self.base_dir, path), 'rb') as f:
+            return pkl.load(f)
 
-    def process(self, data: Dict)->Dict:
+    def process(self, data: Dict) -> Dict:
         """Load entry
 
         Args:
