@@ -38,13 +38,17 @@ from dlk.core import (
     model_config_register,
     model_register,
     scheduler_config_register,
+    scheduler_register,
     loss_config_register,
     loss_register,
     module_config_register,
     module_register,
     optimizer_config_register,
     optimizer_register,
-    scheduler_register
+    adv_method_config_register,
+    adv_method_register,
+    search_method_register,
+    search_method_config_register,
 )
 from dlk.data import (
     datamodule_config_register,
@@ -214,10 +218,10 @@ class BaseConfigParser(object):
                 if os.path.isfile(os.path.join(get_root(), config_base_dir, config_file+'.hjson')):
                     self.config_file = self.load_hjson_file(os.path.join(get_root(), config_base_dir, config_file+'.hjson'))
                 else:
-                    self.config_file = register.get(config_file).default_config
+                    self.config_file = copy.deepcopy(register.get(config_file).default_config)
 
             except Exception as e:
-                logger.error(f"There is an error occur when loading {os.path.join(get_root(), config_base_dir, config_file)}")
+                logger.error(f"You must provide a configure file at {os.path.join(get_root(), config_base_dir, config_file)} or provide `default_config` as a class variable")
                 raise KeyError(e)
         elif isinstance(config_file, Dict):
             self.config_file = config_file
@@ -500,6 +504,7 @@ class BaseConfigParser(object):
         """flat all the _search paras to list
 
         support recursive parser _search now, this means you can add _search/_link/_base paras in _search paras
+        but you should only search currently level paras
 
         Args:
             search: search paras, {"para1": [1,2,3], 'para2': 'list(range(10))'}
@@ -519,7 +524,6 @@ class BaseConfigParser(object):
                 base_config.update(search_para)
                 extend_config = cls(base_config).parser(parser_link=False)
                 result.extend(extend_config)
-                # result.append(base_config)
 
         return result
 
@@ -578,7 +582,7 @@ class BaseConfigParser(object):
         """get catesian prod from named lists
 
         Args:
-            dict_of_list: {'name1': [1,2,3], 'name2': [1,2,3]}
+            dict_of_list: {'name1': [1,2,3], 'name2': "list(range(1, 4))"}
 
         Returns: 
             [{'name1': 1, 'name2': 1}, {'name1': 1, 'name2': 2}, {'name1': 1, 'name2': 3}, ...]
@@ -593,7 +597,7 @@ class BaseConfigParser(object):
         cur_para_search_list = []
         if isinstance(cur_paras, str):
             cur_paras = eval(cur_paras)
-        assert isinstance(cur_paras, list), f"The search options must be list, but you provide {cur_paras}({type(cur_paras)})"
+        assert isinstance(cur_paras, list), f"The search candidates must be list, but you provide {cur_paras}({type(cur_paras)})"
         for para in cur_paras:
             cur_para_search_list.append({cur_name: para})
         if len(dict_of_list) == 0:
@@ -684,11 +688,34 @@ class LinkConfigParser(object):
         return [self.config]
 
 
+module_dir_map = {
+    "task": "dlk/configures/tasks",
+    "manager": "dlk/configures/managers",
+    "callback": "dlk/configures/core/callbacks",
+    "datamodule": "dlk/configures/data/datamodules",
+    "imodel": "dlk/configures/core/imodels",
+    "model": "dlk/configures/core/models",
+    "search_method": "dlk/configures/core/search_methods",
+    "optimizer": "dlk/configures/core/optimizers",
+    "scheduler": "dlk/configures/core/schedulers",
+    "initmethod": "dlk/configures/core/initmethods",
+    "loss": "dlk/configures/core/losses",
+    "encoder": "dlk/configures/core/layers/encoders",
+    "decoder": "dlk/configures/core/layers/decoders",
+    "embedding": "dlk/configures/core/layers/embeddings",
+    "module": "dlk/configures/core/modules",
+    "processor": "dlk/configures/data/processors",
+    "subprocessor": "dlk/configures/data/subprocessors",
+    "postprocessor": "dlk/configures/data/postprocessors",
+    "adv_method": "dlk/configures/core/adv_method",
+}
+
+
 @config_parser_register('task')
 class TaskConfigParser(BaseConfigParser):
     """docstring for TaskConfigParser"""
     def __init__(self, config_file):
-        super(TaskConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/tasks/')
+        super(TaskConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['task'])
 
 
 @config_parser_register('root')
@@ -702,108 +729,120 @@ class RootConfigParser(BaseConfigParser):
 class ManagerConfigParser(BaseConfigParser):
     """docstring for ManagerConfigParser"""
     def __init__(self, config_file):
-        super(ManagerConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/managers/', register=manager_config_register)
+        super(ManagerConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['manager'], register=manager_config_register)
 
 
 @config_parser_register('callback')
 class CallbackConfigParser(BaseConfigParser):
     """docstring for CallbackConfigParser"""
     def __init__(self, config_file):
-        super(CallbackConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/callbacks/', register=callback_config_register)
+        super(CallbackConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['callback'], register=callback_config_register)
 
 
 @config_parser_register('datamodule')
 class DatamoduleConfigParser(BaseConfigParser):
     """docstring for DatamoduleConfigParser"""
     def __init__(self, config_file):
-        super(DatamoduleConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/data/datamodules/', register=datamodule_config_register)
+        super(DatamoduleConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['datamodule'], register=datamodule_config_register)
 
 
 @config_parser_register('imodel')
 class IModelConfigParser(BaseConfigParser):
     """docstring for IModelConfigParser"""
     def __init__(self, config_file):
-        super(IModelConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/imodels/', register=imodel_config_register)
+        super(IModelConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['imodel'], register=imodel_config_register)
 
 
 @config_parser_register('model')
 class ModelConfigParser(BaseConfigParser):
     """docstring for ModelConfigParser"""
     def __init__(self, config_file):
-        super(ModelConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/models/', register=model_config_register)
+        super(ModelConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['model'], register=model_config_register)
 
+@config_parser_register('search_method')
+class SearchMethodConfigParser(BaseConfigParser):
+    """docstring for SearchMethodConfigParser"""
+    def __init__(self, config_file):
+        super(SearchMethodConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['search_method'], register=search_method_config_register)
 
 @config_parser_register('optimizer')
 class OptimizerConfigParser(BaseConfigParser):
     """docstring for OptimizerConfigParser"""
     def __init__(self, config_file):
-        super(OptimizerConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/optimizers/', register=optimizer_config_register)
-
+        super(OptimizerConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['optimizer'], register=optimizer_config_register)
 
 @config_parser_register('scheduler')
 class ScheduleConfigParser(BaseConfigParser):
     """docstring for ScheduleConfigParser"""
     def __init__(self, config_file):
-        super(ScheduleConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/schedulers/', register=scheduler_config_register)
+        super(ScheduleConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['scheduler'], register=scheduler_config_register)
 
 @config_parser_register('initmethod')
 class InitMethodConfigParser(BaseConfigParser):
     """docstring for InitMethodConfigParser"""
     def __init__(self, config_file):
-        super(InitMethodConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/initmethods/', register=initmethod_config_register)
+        super(InitMethodConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['initmethod'], register=initmethod_config_register)
+
+
+@config_parser_register('adv_method')
+class AdvMethodConfigParser(BaseConfigParser):
+    """docstring for AdvMethodConfigParser"""
+    def __init__(self, config_file):
+        super(AdvMethodConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['adv_method'], register=adv_method_config_register)
 
 
 @config_parser_register('loss')
 class LossConfigParser(BaseConfigParser):
     """docstring for LossConfigParser"""
     def __init__(self, config_file):
-        super(LossConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/losses/', register=loss_config_register)
+        super(LossConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['loss'], register=loss_config_register)
 
 
 @config_parser_register('encoder')
 class EncoderConfigParser(BaseConfigParser):
     """docstring for EncoderConfigParser"""
     def __init__(self, config_file):
-        super(EncoderConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/layers/encoders/', register=encoder_config_register)
+        super(EncoderConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['encoder'], register=encoder_config_register)
 
 
 @config_parser_register('decoder')
 class DecoderConfigParser(BaseConfigParser):
     """docstring for DecoderConfigParser"""
     def __init__(self, config_file):
-        super(DecoderConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/layers/decoders/', register=decoder_config_register)
+        super(DecoderConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['decoder'], register=decoder_config_register)
 
 
 @config_parser_register('embedding')
 class EmbeddingConfigParser(BaseConfigParser):
     """docstring for EmbeddingConfigParser"""
     def __init__(self, config_file):
-        super(EmbeddingConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/layers/embeddings/', register=embedding_config_register)
+        super(EmbeddingConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['embedding'], register=embedding_config_register)
 
 
 @config_parser_register('module')
 class ModuleConfigParser(BaseConfigParser):
     """docstring for ModuleConfigParser"""
     def __init__(self, config_file):
-        super(ModuleConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/core/modules/', register=module_config_register)
+        super(ModuleConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['module'], register=module_config_register)
 
 @config_parser_register('processor')
 class ProcessorConfigParser(BaseConfigParser):
     """docstring for ProcessorConfigParser"""
     def __init__(self, config_file):
-        super(ProcessorConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/data/processors/', register=processor_config_register)
+        super(ProcessorConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['processor'], register=processor_config_register)
 
 
 @config_parser_register('subprocessor')
 class SubProcessorConfigParser(BaseConfigParser):
     """docstring for SubProcessorConfigParser"""
     def __init__(self, config_file):
-        super(SubProcessorConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/data/subprocessors/', register=subprocessor_config_register)
+        super(SubProcessorConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['subprocessor'], register=subprocessor_config_register)
 
 
 @config_parser_register('postprocessor')
 class PostProcessorConfigParser(BaseConfigParser):
     """docstring for PostProcessorConfigParser"""
     def __init__(self, config_file):
-        super(PostProcessorConfigParser, self).__init__(config_file, config_base_dir='dlk/configures/data/postprocessors/', register=postprocessor_config_register)
+        super(PostProcessorConfigParser, self).__init__(config_file, config_base_dir=module_dir_map['postprocessor'], register=postprocessor_config_register)
+
 
